// ===========================================================================
//	LOneTimeTask.cp		1999-2002 Metrowerks Corporation.  All rights reserved.
// ===========================================================================
//	Original author: John C. Daub. Thanx to Rick Aurbach for the idea.
//
//	An abstract base class for tasks that are to be performed once at
//	Periodical Devote time (either idle or repeat). The task is performed
//	and then deletes itself.
//
//	This is useful if you need to perform an event "asynchronously" at the
//	next repeat/idle time.
//
//	To use this class, you must subclass it and implement the Perform() method.

#ifdef PowerPlant_PCH
	#include PowerPlant_PCH
#endif

#include "LOneTimeTask.h"


PP_Begin_Namespace_PowerPlant

// ---------------------------------------------------------------------------
//	 LOneTimeTask											[public]
// ---------------------------------------------------------------------------
//	Default constructor (and parameterized).
//
//	Argument specifies the type (EPeriodicalTask) of task

LOneTimeTask::LOneTimeTask(
	EPeriodicTaskType	inTaskType)
{
	mActive		= false;
	
		// Insert into the Periodical queue.
	if (inTaskType == periodicTaskType_Repeat) {
		StartRepeating();
	} else if (inTaskType == periodicTaskType_Idle) {
		StartIdling();
	} else {
		SignalStringLiteral_("Unknown EPeriodicTaskType");
	}
}


// ---------------------------------------------------------------------------
//	~LOneTimeTask											[public, virtual]
// ---------------------------------------------------------------------------
//	Destructor

LOneTimeTask::~LOneTimeTask()
{
}


// ---------------------------------------------------------------------------
//	 SpendTime												[public, virtual]
// ---------------------------------------------------------------------------
//	Performs the task and then deletes itself.

void
LOneTimeTask::SpendTime(
	const EventRecord&	/*inMacEvent*/)
{
	if (not mActive) {
	
		mActive = true;
		
		Perform();

		delete this;		// ~LPeriodical() will remove this
							//	from whichever queue it's in.
	}
}

PP_End_Namespace_PowerPlant